@@ -26,7 +26,7 @@
 #'
 #' @param register String with abbreviation of register to query,
 #' either "EUCTR", "CTGOV", "ISRCTN" or "CTIS". Not needed
-#' if \code{queryterm} provides a query's full URL.
+#' if \code{queryterm} provides a full URL to query results.
 #'
 #' @param querytoupdate Either the word "last", or the row number of
 #' a query in the data frame returned by \link{dbQueryHistory} that
@@ -109,9 +109,9 @@
 #' dbc <- nodbi::src_sqlite(collection = "my_collection")
 #'
 #' # Retrieve protocol- and results-related information
-#' # on a single trial identified by its EU number
+#' # on two specific trials identified by their EU number
 #' ctrLoadQueryIntoDb(
-#'   queryterm = "2013-001291-38",
+#'   queryterm = "2005-001267-63+OR+2008-003606-33",
 #'   register = "EUCTR",
 #'   euctrresults = TRUE,
 #'   con = dbc
@@ -135,7 +135,7 @@
 #'   con = dbc
 #' )
 #'
-#' # Retrieve information on trials in CTIS
+#' # Retrieve all information on completed trials in CTIS
 #' ctrLoadQueryIntoDb(
 #'   queryterm = "https://euclinicaltrials.eu/app/#/search?status=Ended",
 #'   con = dbc
@@ -2702,7 +2702,7 @@ ctrLoadQueryIntoDbCtis <- function(
   } # end if documents.path
 
   ## inform user on final import outcome
-  message("\n= Imported / updated ",
+  message("= Imported / updated ",
           paste0(c(imported$n, resAll), collapse = " / "),
           " records on ", resultsEuNumTrials, " trial(s)")
 
